@@ -15,11 +15,17 @@ class PhonesModel : public QAbstractListModel
 {
     Q_OBJECT
 public:
+    enum Roles {
+        NumberRole = Qt::DisplayRole,
+        TypeLabelRole = Qt::UserRole + 1,
+    };
+
     explicit PhonesModel(Addressee *a);
 
     bool setData(const QModelIndex &index, const QVariant &value, int role) override;
     QVariant data(const QModelIndex &index, int role) const override;
     int rowCount(const QModelIndex &parent = {}) const override;
+    QHash<int, QByteArray> roleNames() const override;
 
     Q_SCRIPTABLE void addPhoneNumber(const QString &number);
     Q_SCRIPTABLE void removePhoneNumber(const QString &number);
